@@ -1,3 +1,4 @@
+import copy
 import json
 import logging
 import warnings
@@ -123,7 +124,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
 
         # retry default options, use values provided by the caller to update
         # the default retry options
-        self.retry = RETRY
+        self.retry = copy.deepcopy(RETRY)
         for k, v in kwargs.items():
             if k.startswith("retry_"):
 
@@ -268,7 +269,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         """
 
         # create endpoint url to fetch new tokens
-        url = "%(endpoint)s/oauth2/token" % {"endpoint": self.user_api_url}
+        url = f"{self.user_api_url}/oauth2/token"
 
         session = self._new_session()
 
@@ -326,7 +327,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         # construct headers to be used for all requests
         headers = dict(HEADERS)
         if access_token is not None:
-            authorization = "Bearer %(token)s" % {"token": self.access_token}
+            authorization = f"Bearer {self.access_token}"
             headers["Authorization"] = authorization
 
         session = self._requests.Session()
@@ -364,6 +365,8 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
                 res = func(url, timeout=self.timeout_secs, **kwargs)
             except self._requests.exceptions.RetryError as ex:
                 raise RetryError(None, ex.args[0])
+            except self._requests.exceptions.ConnectionError as ex:
+                raise ConnectionError(None, ex) from ex
 
             # check for failed authorization
             if retry_count == 0 and res.status_code == 401:
