@@ -1114,6 +1114,7 @@ class TopicApiBaseMixin:
         project_id,
         query=None,
         scroll="5m",
+        preserve_order=False,
         count=1000,
         fields=None,
         highlight=None,
@@ -1137,6 +1138,8 @@ class TopicApiBaseMixin:
             See https://www.elastic.co/guide/en/elasticsearch
             /reference/current/search-request-scroll.html
             for more details.
+        :param preserve_order: This will cause the scroll to paginate with preserving the order.
+            Note that this can be an extremely expensive operation and can easily lead to unpredictable results, use with caution
         :param count: The number of results fetched per batch. You only need
             to adjust this if you e.g. have very big documents. The maximum
             value that can be set is 10'000.
@@ -1165,10 +1168,9 @@ class TopicApiBaseMixin:
 
         Example::
 
-        >>> for item in client.scan(project_id='Sz7LLLbyTzy_SddblwIxaA', query='country:CH AND plants',
-        ...                         count=500, scroll='1m'):
-                # process matched item
-
+            >>> for item in client.scan(project_id='Sz7LLLbyTzy_SddblwIxaA', query='country:CH AND plants',
+            ...                         count=500, scroll='1m', preserve_order=True):
+                    # process matched item
         """
         assert scroll, "`scroll` cannot be empty for scan."
         if options:
@@ -1187,6 +1189,7 @@ class TopicApiBaseMixin:
         args = {
             "query": query,
             "scroll": scroll,
+            "preserve_order": preserve_order,
             "count": min(count, 10000),
             "child_count": min(child_count, 100),
             "fields": fields,
@@ -1561,19 +1564,19 @@ class TopicApiBaseMixin:
         :param options: Dictionary of options that influence the result-set.
             Valid options are:
 
-                - `template_params` dict containing the query template parameters
-                - `select_suggesters` (optional) list containing suggesters to be used.
+            - `template_params` dict containing the query template parameters
+            - `select_suggesters` (optional) list containing suggesters to be used.
 
             If no suggesters are selected, all suggesters are executed by default.
             Available suggesters:
 
-                - "facet_value": Complete on facet-values that have "autocomplete" enabled (Exact Search)
-                - "facet_name: Help to find the correct facet
-                - "content_phrase": Complete on key-phrases + item-title (Fuzzy Search) added via NLP-Tagger
-                - "saved_search": Complete on queries saved by the user
-                - "popular_query": Complete on popular queries on the project, filtered by user_id (optional)
-                - "search_history": Triggered only to pre-populate and show default-suggestions.
-                                    Returns last-N searches, filtered by project_id and user_id.
+            - "facet_value": Complete on facet-values that have "autocomplete" enabled (Exact Search)
+            - "facet_name: Help to find the correct facet
+            - "content_phrase": Complete on key-phrases + item-title (Fuzzy Search) added via NLP-Tagger
+            - "saved_search": Complete on queries saved by the user
+            - "popular_query": Complete on popular queries on the project, filtered by user_id (optional)
+            - "search_history": Triggered only to pre-populate and show default-suggestions.
+              Returns last-N searches, filtered by project_id and user_id.
 
         :param filter_query: Squirro query to limit the typeahead suggestions.
             Must be of type `string`. Defaults to `None` if not specified. As
