@@ -49,6 +49,7 @@ class CommunityTypesMixin(object):
         start=None,
         count=-1,
         community_partial_name=None,
+        include_count_of_items=False,
     ):
         """Returns a community types for a project
         given the community_type_id
@@ -64,6 +65,9 @@ class CommunityTypesMixin(object):
             number of communities are returned. To return all communities, set
             to -1. Defaults to -1.
         :param community_partial_name: Argument to filter communities by name.
+        :param include_count_of_items: Boolean argument to include the count of
+            items belonging to the communities of community type `community_type_id`.
+            Defaults to False.
 
         Example::
 
@@ -95,6 +99,7 @@ class CommunityTypesMixin(object):
             "start": start,
             "count": count,
             "community_partial_name": community_partial_name,
+            "include_count_of_items": include_count_of_items,
         }
         res = self._perform_request("get", url, params=params)
         return self._process_response(res)
