@@ -52,9 +52,9 @@ class MachineLearningMixin:
         :param ml_models: Directory with ml_models to be uploaded into the workflow
             path
         :param type: Optional parameter to define type of the Machine
-            learning workflow
+            learning workflow. Possible values are `other`, `query`, `query_default`,
+            `ais`, `published`. If not specified, the default type is `other`.
         """
-
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
         headers = {"Content-Type": "application/json"}
 
@@ -151,7 +151,8 @@ class MachineLearningMixin:
         :param ml_models: Directory with ml_models to be uploaded into the workflow
             path.
         :param type: Optional parameter to define type of the Machine
-            learning workflow
+            learning workflow. Possible values are `other`, `query`, `query_default`,
+            `ais`, `published`. If not specified, the default type is `other`.
         """
         base_url = "{}/v0/{}/projects/{}/machinelearning_workflows"
         headers = {"Content-Type": "application/json"}
@@ -243,8 +244,10 @@ class MachineLearningMixin:
         :param ml_workflow_id: Id of the Machine Learning workflow.
         :param name: Optional name of Machine learning workflow. If not
             specified, the name of the workflow will be the same as the original one.
-        :param type: Optional type of Machine learning workflow. If not
-            specified, the type of the workflow will be the same as the original one.
+        :param type: Optional parameter to define type of the Machine
+            learning workflow. Possible values are `other`, `query`, `query_default`,
+            `ais`, `published`. If not specified, the type of the workflow will be the
+            same as the original one.
         """
         url = (
             f"{self.topic_api_url}/v0/{self.tenant}/projects/{project_id}"
