@@ -334,6 +334,22 @@ class PipelineWorkflowMixin:
             only with the rerun from index, in order to rerun only the items returned by
             the query.
             [1] https://go.squirro.com/query-syntax
+
+        Example::
+
+            >>> client.rerun_pipeline_workflow(
+            ...    "EcKKf_dxRe-xrCB8g1fGCg",
+            ...    "Or0UiK-qROeE1x8kVlBZkQ",
+            ...    from_index=True,
+            ...    step_ids=["aiNJX35dRhCfqc3a3l84PA", "qsXDOkMvQ-62-iM7O1Fp5w"],
+            ...    query="source:g2hqOvX8SZmR7R2RPmMlDw")
+
+        The above example will invoke rerun from index for the worklflow with id
+        `Or0UiK-qROeE1x8kVlBZkQ` of the project with id `EcKKf_dxRe-xrCB8g1fGCg`, using
+        only the 2 provided steps identified by their ids (steps are alredy part of the
+        workflow), and only on the items of the source with id `g2hqOvX8SZmR7R2RPmMlDw`
+        (the workflow can be configured to be used by many sources, but we want to rerun
+        only on the items of a specific configured source).
         """
         headers = {"Content-Type": "application/json"}
 
