@@ -74,7 +74,11 @@ class UserApiMixin:
         return self._process_response(res)
 
     def change_user_password(
-        self, user_id, current_password, new_password, new_password_confirm,
+        self,
+        user_id,
+        current_password,
+        new_password,
+        new_password_confirm,
     ):
         """
         Change a user's password.
@@ -105,7 +109,9 @@ class UserApiMixin:
     def get_users_password_policy(self):
         """Retrieve the password policy for users' passwords."""
         url = "{endpoint}/{version}/{tenant}/users/password_policy".format(
-            endpoint=self.user_api_url, version=self.version, tenant=self.tenant,
+            endpoint=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
         res = self._perform_request("get", url)
         return self._process_response(res)
@@ -375,7 +381,9 @@ class UserApiMixin:
             params["include_config"] = include_config
 
         url = "{ep}/{version}/{tenant}/users".format(
-            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
 
         res = self._perform_request("get", url, params=params)
@@ -486,7 +494,7 @@ class UserApiMixin:
         params = {}
         params["msexchuid"] = msexchuid
 
-        res = self._perform_request("get", url, params)
+        res = self._perform_request("get", url, params=params)
         return self._process_response(res, [200])
 
     def add_project_member(self, project_id, role, user_id=None, group_id=None):
@@ -619,7 +627,9 @@ class UserApiMixin:
             ]
         """
         url = "{ep}/{version}/{tenant}/groups".format(
-            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
         res = self._perform_request("get", url)
         return self._process_response(res, [200])
@@ -639,7 +649,9 @@ class UserApiMixin:
             }
         """
         url = "{ep}/{version}/{tenant}/groups".format(
-            ep=self.user_api_url, version=self.version, tenant=self.tenant,
+            ep=self.user_api_url,
+            version=self.version,
+            tenant=self.tenant,
         )
         res = self._perform_request("post", url, data={"name": name})
         return self._process_response(res, [201])
